@@ -17,7 +17,7 @@ DRBL_SCRIPT_PATH="${DRBL_SCRIPT_PATH:-/opt/drbl/}"
 check_if_root
 
 # Settings
-SL_ISO_URL_EXAMPLE="http://prdownloads.sourceforge.net/clonezilla/clonezilla-live-1.2.2-26.iso?download"
+SL_ISO_URL_EXAMPLE="http://prdownloads.sourceforge.net/clonezilla/clonezilla-live-1.2.5-5-i686.iso"
 
 # List all supported SL_NAME
 # // On 2009/05/25, we remove the support for PLD, INSERT, PUD, since those projects are not developed any more. As for GeeXbox, since we do not have time, it's removed, too.
@@ -31,14 +31,21 @@ buffer_ratio_for_iso_to_container="1.25"
 # we estimate it as 3 times of the initrd. For some distribution we might overwrite this value if necessary.
 client_ram_to_initrd_ratio="3"
 
+#
+batch_mode="off"
+# Prompt messages after installation.
+booting_messages="on"
+
 # Functions
 USAGE() {
   echo "Load small GNU/Linux ($supported_SL_dists) Linux to DRBL environment."
   echo "Usage: $0 [OPTION] [SL-ISO|SL-INDEX]"
   echo "OPTION:"
   language_help_prompt_by_idx_no
+  echo "-b, --batch-mode   Run clone in batch mode."
   echo "-i, --install ISO:        Load Small Linux ISO into DRBL environment, you must put the iso file in the current working dir." 
   echo "-d, --distribution DIST:  Assign the small GNU/Linux distribution as DIST. Available names are: $supported_SL_dists."
+  echo "-n, --no-prompt-boot-message  Skip the prompt messages about booting via PXE or etherboot in the end of execution."
   echo "-u, --uninstall DIST:     Uninstall Small Linux DIST."
   echo "-V, --dist-version VER:   Assign the version of small GNU/Linux version number as VER."
   echo "-v, --verbose:     Verbose mode."
@@ -86,12 +93,22 @@ prepare_param_in_pxe_cfg(){
        use_modified_init="no"
        append_param_in_pxe_cfg="initrd=$nbi_initrd"
        ;;
-    clonezilla-live|gparted-live)
+    clonezilla-live)
        # Find the IP address of this server. Here we choose the first one in the list, since it's just an example.
        server_IP="$(LC_ALL=C get-all-nic-ip -i | awk -F" " '{print $1}')"
        if [ -z "$cl_gp_boot_param" ]; then
 	 # We do not put ip=frommedia because the /etc/resolv.conf got in live-initramfs won't exist after initramfs is done.        
-         append_param_in_pxe_cfg="initrd=$nbi_initrd boot=live union=aufs noswap noprompt nolocales vga=788 fetch=tftp://$server_IP/$squashfs_file"
+         append_param_in_pxe_cfg="initrd=$nbi_initrd boot=live union=aufs noswap noprompt nolocales vga=788 fetch=tftp://$server_IP/$squashfs_file ocs_server=\"$server_IP\""
+       else
+         append_param_in_pxe_cfg="initrd=$nbi_initrd $cl_gp_boot_param noprompt fetch=tftp://$server_IP/$squashfs_file ocs_server=\"$server_IP\""
+       fi
+       ;;
+    gparted-live)
+       # Find the IP address of this server. Here we choose the first one in the list, since it's just an example.
+       server_IP="$(LC_ALL=C get-all-nic-ip -i | awk -F" " '{print $1}')"
+       if [ -z "$cl_gp_boot_param" ]; then
+	 # We do not put ip=frommedia because the /etc/resolv.conf got in live-initramfs won't exist after initramfs is done.        
+         append_param_in_pxe_cfg="initrd=$nbi_initrd boot=live union=aufs noswap noprompt nolocales vga=788 fetch=tftp://$server_IP/$squashfs_file "
        else
          append_param_in_pxe_cfg="initrd=$nbi_initrd $cl_gp_boot_param noprompt fetch=tftp://$server_IP/$squashfs_file"
        fi
@@ -224,7 +241,7 @@ create_linuxrc_pxe_initrd_with_rootfs_inserted(){
     
     # Remove the working dir
     echo 'Removing temporary working dir...'
-    [ -d "$wd" -a -n "$wd" ] && rm -rf $wd
+    [ -d "$wd" -a -n "$(echo $wd | grep "drbl_sl_wd")" ] && rm -rf $wd
     
     # Copy the linux kernel
     cp -f "$kernel" $pxecfg_pd/$nbi_kernel
@@ -336,8 +353,8 @@ put_kernel_initrd_root_fs_on_pxe_server() {
 #
 umount_and_clean_tmp_working_dirs(){
   umount $isomnt
-  [ -d "$isomnt" -a -n "$isomnt" ] && rm -rf "$isomnt"
-  [ -d "$wd" -a -n "$wd" ] && rm -rf "$wd"
+  [ -d "$isomnt" -a -n "$(echo $isomnt | grep "drblsl_tmp")" ] && rm -rf $isomnt
+  [ -d "$wd" -a -n "$(echo $wd | grep "drbl_sl_wd")" ] && rm -rf $wd
 } # end of umount_and_clean_tmp_working_dirs
 #
 get_SL_OS_NAME(){
@@ -473,22 +490,24 @@ install_SL(){
   esac
   
   #
-  echo "$msg_delimiter_star_line"
-  echo "$msg_this_script_will_create_SL_diskless: $SL_FULL_NAME"
-  echo -n "$msg_are_u_sure_u_want_to_continue [Y/n] "
-  read confirm_ans
-  case "$confirm_ans" in
-    n|N|[nN][oO])
-       echo "$msg_program_stop"
-       exit 1
-       ;;
-    *)
-       echo "$msg_ok_let_do_it"
-       ;;
-  esac
+  if [ "$batch_mode" != "on" ]; then
+    echo "$msg_delimiter_star_line"
+    echo "$msg_this_script_will_create_SL_diskless: $SL_FULL_NAME"
+    echo -n "$msg_are_u_sure_u_want_to_continue [Y/n] "
+    read confirm_ans
+    case "$confirm_ans" in
+      n|N|[nN][oO])
+         echo "$msg_program_stop"
+         exit 1
+         ;;
+      *)
+         echo "$msg_ok_let_do_it"
+         ;;
+    esac
+  fi
   
   #
-  isomnt="$(mktemp -d /tmp/sl.XXXXXX)"
+  isomnt="$(mktemp -d /tmp/drblsl_tmp.XXXXXX)"
   wd="$(mktemp -d drbl_sl_wd.XXXXXX)"
   echo "Mounting the iso file $SL_ISO at mounting point $isomnt"
   mount -o loop $SL_ISO $isomnt
@@ -626,11 +645,19 @@ label $SL_NAME
 
 SL_PXE
   fi
+  # Put the version number
+cat <<-SL_INFO_PXE >> $pxecfg_pd/${SL_NAME}-info.txt
+$SL_FULL_NAME version: $SL_VER
+Files were extracted from "$(basename $SL_ISO)"
+SL_INFO_PXE
+  # Put the prompt messages
   echo "$msg_delimiter_star_line"
-  [ "$BOOTUP" = "color" ] && $SETCOLOR_WARNING
-  echo "$msg_all_set_you_can_turn_on_clients"
-  echo "$msg_note! $msg_etherboot_5_4_is_required"
-  [ "$BOOTUP" = "color" ] && $SETCOLOR_NORMAL
+  if [ "$booting_messages" = "on" ]; then
+    [ "$BOOTUP" = "color" ] && $SETCOLOR_WARNING
+    echo "$msg_all_set_you_can_turn_on_clients"
+    echo "$msg_note! $msg_etherboot_5_4_is_required"
+    [ "$BOOTUP" = "color" ] && $SETCOLOR_NORMAL
+  fi
 } # end of install_SL
 
 # 
@@ -669,6 +696,7 @@ check_if_root
 # Parse command-line options
 while [ $# -gt 0 ]; do
   case "$1" in
+    -b|--batch-mode) shift; batch_mode="on" ;;
     -l|--language)
             shift
             if [ -z "$(echo $1 |grep ^-.)" ]; then
@@ -696,6 +724,7 @@ while [ $# -gt 0 ]; do
 	  shift
         fi
 	;;
+    -n|--no-prompt-boot-message) shift; booting_messages="off";;
     -u|--uninstall)
         shift; mode="uninstall"
         if [ -z "$(echo $1 |grep ^-.)" ]; then
